@@ -15,10 +15,10 @@ class Activation(Layer):
     Example:
 
     >>> layer = keras.layers.Activation('relu')
-    >>> layer([-3.0, -1.0, 0.0, 2.0])
+    >>> layer(np.array([-3.0, -1.0, 0.0, 2.0]))
     [0.0, 0.0, 0.0, 2.0]
     >>> layer = keras.layers.Activation(keras.activations.relu)
-    >>> layer([-3.0, -1.0, 0.0, 2.0])
+    >>> layer(np.array([-3.0, -1.0, 0.0, 2.0]))
     [0.0, 0.0, 0.0, 2.0]
     """
 
@@ -27,6 +27,8 @@ class Activation(Layer):
         self.supports_masking = True
         self.activation = activations.get(activation)
 
+        self._build_at_init()
+
     def call(self, inputs):
         return self.activation(inputs)
 
