@@ -50,7 +50,8 @@ class LeakyReLU(Layer):
             )
         self.negative_slope = negative_slope
         self.supports_masking = True
-        self.built = True
+
+        self._build_at_init()
 
     def call(self, inputs):
         return activations.leaky_relu(
