@@ -461,7 +461,7 @@ def is_tf_dataset(dataset):
     return _mro_matches(
         dataset,
         class_names=("DatasetV2", "Dataset"),
-        module_prefixes=(
+        module_substrings=(
             "tensorflow.python.data",  # TF classic
             "tensorflow.data",  # newer TF paths
         ),
@@ -480,7 +480,9 @@ def is_torch_dataset(dataset):
     return _mro_matches(dataset, ("Dataset",), ("torch.utils.data",))
 
 
-def _mro_matches(dataset, class_names, module_prefixes):
+def _mro_matches(
+    dataset, class_names, module_prefixes=(), module_substrings=()
+):
     if not hasattr(dataset, "__class__"):
         return False
     for parent in dataset.__class__.__mro__:
@@ -488,6 +490,8 @@ def _mro_matches(dataset, class_names, module_prefixes):
             mod = str(parent.__module__)
             if any(mod.startswith(pref) for pref in module_prefixes):
                 return True
+            if any(subs in mod for subs in module_substrings):
+                return True
     return False
 
 
