@@ -39,6 +39,15 @@ class LazyModule:
         return f"LazyModule({self.name})"
 
 
+class OrbaxLazyModule(LazyModule):
+    def initialize(self):
+        try:
+            parent_module = importlib.import_module("orbax.checkpoint")
+            self.module = parent_module.v1
+        except ImportError:
+            raise ImportError(self.import_error_msg)
+
+
 tensorflow = LazyModule("tensorflow")
 gfile = LazyModule("tensorflow.io.gfile", pip_name="tensorflow")
 tensorflow_io = LazyModule("tensorflow_io")
@@ -59,3 +68,12 @@ optree = LazyModule("optree")
 dmtree = LazyModule("tree")
 tf2onnx = LazyModule("tf2onnx")
 grain = LazyModule("grain")
+litert = LazyModule("ai_edge_litert")
+ocp = OrbaxLazyModule(
+    "orbax.checkpoint.v1",
+    pip_name="orbax-checkpoint",
+    import_error_msg=(
+        "OrbaxCheckpoint requires the 'orbax-checkpoint' package. "
+        "You can install it via pip install orbax-checkpoint"
+    ),
+)
